﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using Infragistics.Windows.Tiles;

namespace XamTilesControl_SelectedItem.SelectionBehavior
{
    public class SelectionAdvisor : DependencyObject
    {
        #region IsSelected
        public static bool GetIsSelected(DependencyObject obj)
        {
            return (bool)obj.GetValue(IsSelectedProperty);
        }

        public static void SetIsSelected(DependencyObject obj, bool value)
        {
            obj.SetValue(IsSelectedProperty, value);
        }

        public static readonly DependencyProperty IsSelectedProperty =
            DependencyProperty.RegisterAttached("IsSelected", typeof(bool), typeof(SelectionAdvisor),
            new UIPropertyMetadata(false));

        
        #endregion

        #region SelectedTile
        public static Tile GetSelectedTile(DependencyObject obj)
        {
            return (Tile)obj.GetValue(SelectedTileProperty);
        }

        public static void SetSelectedTile(DependencyObject obj, Tile value)
        {
            obj.SetValue(SelectedTileProperty, value);
        }

        public static readonly DependencyProperty SelectedTileProperty =
            DependencyProperty.RegisterAttached("SelectedTile", typeof(Tile), typeof(SelectionAdvisor),
            new UIPropertyMetadata(null, new PropertyChangedCallback(OnSelectedTileChanged)));
        private static void OnSelectedTileChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            Tile newTile = e.NewValue as Tile;
            Tile oldTIle = e.OldValue as Tile;

            if (newTile != null)
            {
                // Select New Tile
                newTile.SetValue(IsSelectedProperty, true);
            }
            if (oldTIle != null)
            {
                bool allowsMultipleSelection = (bool)(d as XamTilesControl).GetValue(AllowMultipleSelectionProperty);

                if (!allowsMultipleSelection)
                {
                    // Deselect Old Tile If AllowMultipleSelectionProperty is false
                    oldTIle.SetValue(IsSelectedProperty, false);
                }
            }
        }
        #endregion

        #region AllowMultipleSelection
        public static bool GetAllowMultipleSelection(DependencyObject obj)
        {
            return (bool)obj.GetValue(AllowMultipleSelectionProperty);
        }

        public static void SetAllowMultipleSelection(DependencyObject obj, bool value)
        {
            obj.SetValue(AllowMultipleSelectionProperty, value);
        }

        public static readonly DependencyProperty AllowMultipleSelectionProperty =
            DependencyProperty.RegisterAttached("AllowMultipleSelection", typeof(bool),
            typeof(SelectionAdvisor), new UIPropertyMetadata(false, new PropertyChangedCallback(OnAllowMultipleSelectionChanged)));


        private static void OnAllowMultipleSelectionChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            XamTilesControl tileControl = d as XamTilesControl;
            Tile selectedTile = tileControl.GetValue(SelectedTileProperty) as Tile;
            bool allowMulti = (bool)e.NewValue;
            if (!allowMulti)
            {
                // Clear all Selected Tiles
                if (tileControl.Items.Count != 0)
                {
                    foreach (object obj in tileControl.Items)
                    {
                        Tile tile = tileControl.TileFromItem(obj);
                        if (tile != null && tile != selectedTile)
                        {
                            tile.SetValue(IsSelectedProperty, false);
                        }
                    }
                }
            }
        }
        #endregion
    }
}
